if ($Server::CarColorSchemesVersion > 4) return;

$Server::CarColorSchemesVersion = 4;

package CarColorSchemes
{
    function Vehicle::setNodeColor(%veh, %node, %color)
    {
        %this = %veh.getDatablock();
        if(%node $= "ALL" && %this.storedColorScheme) //We're trying to paint ALL nodes on a car that will use this script
        {
            %target = %veh.colorSchemeTarget;

            if(%target >= %veh.numColorSchemeTargets || %veh.numColorSchemeTargets < 2)
            {
                parent::setNodeColor(%veh, %node, %color);
                return;
            }//Don't try to paint a section that doesn't exist.
            //Don't bother with the script if there's only one section.

            %veh.colorSchemeColor[%target] = %color; //Assign the painted color to the target's saved color.

            if(%this.colorSchemeIdentifier !$= "")
            {
                %veh.spawnbrick.colorSchemeColor[%this.colorSchemeIdentifier, %target] = %color;
            }

            //The base color is treated differently than painting individual sections.
            if(%target == 0) //If we're targeting the vehicle's base color,
            {
                parent::setNodeColor(%veh,%node,%color); //paint everything like usual.

                if(%veh.partsBot !$= "")
                {
                    %veh.partsBot.setNodeColor("ALL", %color);
                }

                //With everything painted, we now need to restore the colors set for the secondary areas.
                for(%i = 1; %i < %veh.numColorSchemeTargets; %i++)
                {
                    if(strlen(%veh.colorSchemeNodes[%i]) != 0) //If this target has no nodes defined, don't do anything.
                    {
                        %alpha = getWord(%veh.colorSchemeColor[%i], 3);
                        %default = %veh.colorSchemeDefault[%i];

                        if(%alpha == 1 || (%default != 0 && getWord(%veh.colorSchemeColor[%default], 3) == 1)) //Opaque OR it has a specified, opaque default
                        { //If a color is NOT opaque, it's disabled. If it has a default, use that instead. If the default is disabled, don't do anything.
                            if(%alpha != 1) //Non-opaque, which means it needs to use its specified default
                            {
                                %revisedTarget = %veh.colorSchemeDefault[%i];
                            }
                            else //Opaque, which means this target has its own color to use.
                            {
                                %revisedTarget = %i;
                            }

                            %count = getWordCount(%veh.colorSchemeNodes[%i]) - 1;

                            for(%j = 0; %j <= %count; %j++) //Each node in the node list...
                            {
                                %part = getWord(%veh.colorSchemeNodes[%i], %j);    //Find out which part of the car we're looking at
                                if(%part !$= "ALL" && %part !$= "")
                                    %veh.setNodeColor(%part, %veh.colorSchemeColor[%revisedTarget]);
                            }
                        }
                    }
                }
            } //Finished dealing with base color.
            else if(strlen(%veh.colorSchemeNodes[%target]) != 0) //If we are targeting a specific section...
            {
                %count = getWordCount(%veh.colorSchemeNodes[%target]) - 1;
                for(%j = 0; %j <= %count; %j++) //Each node in the node list...
                {
                    %part = getWord(%veh.colorSchemeNodes[%target], %j);    //Find out which part of the car we're looking at
                    if(%part !$= "ALL" && %part !$= "")
                        %veh.setNodeColor(%part, %veh.colorSchemeColor[%target]);
                }

                for(%i = 1; %i < %veh.numColorSchemeTargets; %i++) //Run through each of the targets
                {
                    if(%veh.colorSchemeDefault[%i] == %target && getWord(%veh.colorSchemeColor[%i], 3) != 1) //If they use this color as default, AND are disabled...
                    {   //Color them too
                        %count = getWordCount(%veh.colorSchemeNodes[%i]) - 1;
                        for(%j = 0; %j <= %count; %j++) //Each node in the node list...
                        {
                            %part = getWord(%veh.colorSchemeNodes[%i], %j); //Find out which part of the car we're looking at
                            if(%part !$= "ALL" && %part !$= "")
                                %veh.setNodeColor(%part, %veh.colorSchemeColor[%target]); //Paint them like the current target
                        }
                    }
                }
            }


        }
        else parent::setNodeColor(%veh, %node, %color);
    }

    function fxDTSBrick::colorVehicle(%this)
    {
        if(%this.reColorVehicle $= "1" && %this.vehicleDataBlock.storedColorScheme)
        {   //If the car uses a color scheme, recoloring the brick should change the base color, not the vehicle's current paint target.
            %veh = %this.vehicle;
            %temp = %veh.colorSchemeTarget;
            %veh.colorSchemeTarget = 0; //%veh.brickcolorSchemeTarget; //If not specified, this will act like 0 (the base color)
            parent::colorVehicle(%this, %veh);
            %veh.colorSchemeTarget = %temp;
            return;
        }
        else
        {
            return parent::colorVehicle(%this);
        }
    }
};
activatepackage(CarColorSchemes);